==> pcdl-3.3.0.tar.gz: pcdl-3.3.0/man/docstring/mcdsts.__init__.md <==
# mcdsts = pcdl.TimeSeries('path/to/output')


## input:
```
            output_path: string, default '.'
                relative or absolute path to the directory where
                the PhysiCell output files are stored.

            custom_data_type: dictionary; default is {}
                variable to specify custom_data variable types
                besides float (int, bool, str) like this: {var: dtype, ...}.
                downstream float and int will be handled as numeric,
                bool as Boolean, and str as categorical data.

            load: boole; default True
                should the whole time series data, all time steps, straight at
                object initialization be read and stored to mcdsts.l_mcds?

            microenv: boole; default True
                should the microenvironment be extracted?
                setting microenv to False will use less memory and speed up
                processing, similar to the original pyMCDS_cells.py script.

            graph: boole; default True
                should neighbor graph and attached graph be extracted?
                setting graph to False will use less memory and speed up processing.

            physiboss: boole; default True
                should physiboss state data extracted, if found?
                setting physiboss to False will use less memory and speed up processing.

            settingxml: string; default PhysiCell_settings.xml
                from which settings.xml should the substrate and cell type
                ID label mapping be extracted?
                set to None or False if the xml file is missing!

            verbose: boole; default True
                setting verbose to False for less text output while processing.

```

## output:
```
            mcdsts: pyMCDSts class instance
                this instance offers functions to process all stored time steps
                from a simulation.

```

## description:
```
            TimeSeries.__init__ will call pyMCDSts.__init__ that generates a mcdsts
            class instance. this instance offers functions to process all time steps
            in the output_path directory.
        
```

==> pcdl-3.3.1.tar.gz: pcdl-3.3.1/man/docstring/mcdsts.__init__.md <==
# mcdsts = pcdl.TimeSeries('path/to/output')


## input:
```
            output_path: string, default '.'
                relative or absolute path to the directory where
                the PhysiCell output files are stored.

            custom_data_type: dictionary; default is {}
                variable to specify custom_data variable types
                besides float (int, bool, str) like this: {var: dtype, ...}.
                downstream float and int will be handled as numeric,
                bool as Boolean, and str as categorical data.

            load: boole; default True
                should the whole time series data, all time steps, straight at
                object initialization be read and stored to mcdsts.l_mcds?

            microenv: boole; default True
                should the microenvironment data be loaded?
                setting microenv to False will use less memory and speed up
                processing, similar to the original pyMCDS_cells.py script.

            graph: boole; default True
                should neighbor graph and attached graph be loaded?
                setting graph to False will use less memory and speed up processing.

            physiboss: boole; default True
                should physiboss state data be loaded, if found?
                setting physiboss to False will use less memory and speed up processing.

            settingxml: string; default PhysiCell_settings.xml
                the settings.xml that is loaded, from which the cell type ID
                label mapping, is extracted, if this information is not found
                in the output xml file.
                set to None or False if the xml file is missing!

            verbose: boole; default True
                setting verbose to False for less text output while processing.

```

## output:
```
            mcdsts: pyMCDSts class instance
                this instance offers functions to process all stored time steps
                from a simulation.

```

## description:
```
            TimeSeries.__init__ will call pyMCDSts.__init__ that generates a mcdsts
            class instance. this instance offers functions to process all time steps
            in the output_path directory.
        
```
